Ручное программирование
Пред. | Глава 4. Программирование эфира | След.

## Ручное программирование

Ручное управление позволяет вручную указать метки для использования в качестве виртуального плейлиста на ближайшее время. Например, если менеджер станции хочет, чтобы ближайший час играл рок с женским вокалом, он может отправить jabber-боту команду play:

    play rock +female

Эта функция доступна и в командной строке:

    ardj play rock +female

Управление из командной строки предназначено, в основном, для использования внутри скриптов. Пример конфигурации, включающей на время прямого эфира спокойную иструментальную музыку, можно найти в папке `doc/examples/custom-playlist-on-live`.

Пред. | Наверх | След.
Глава 4. Программирование эфира | Начало | Управление очередью (заказы)